@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::GENEHACK;
 {
-  $Dist::Zilla::PluginBundle::GENEHACK::VERSION = '0.3';
+  $Dist::Zilla::PluginBundle::GENEHACK::VERSION = '0.4';
 }
 BEGIN {
   $Dist::Zilla::PluginBundle::GENEHACK::AUTHORITY = 'cpan:GENEHACK';
@@ -36,7 +36,7 @@ use Dist::Zilla::Plugin::PkgVersion;
 use Dist::Zilla::Plugin::PodCoverageTests;
 use Dist::Zilla::Plugin::PodSyntaxTests;
 use Dist::Zilla::Plugin::PodWeaver;
-use Dist::Zilla::Plugin::ReadmeFromPod;
+use Dist::Zilla::Plugin::ReadmeMarkdownFromPod;
 use Dist::Zilla::Plugin::Repository;
 use Dist::Zilla::Plugin::TaskWeaver;
 use Dist::Zilla::Plugin::Test::Compile;
@@ -116,8 +116,11 @@ sub configure {
     # auto-make INSTALL
     'InstallGuide' ,
 
-    # auto-generate a README
-    'ReadmeFromPod' ,
+    # auto-generate a README.mkdn
+    'ReadmeMarkdownFromPod' ,
+
+    # and copy it from the build
+    [ 'CopyFilesFromBuild' => { copy => 'README.mkdn' } ],
 
     # munge Changes
     'NextRelease' ,
@@ -142,6 +145,9 @@ sub configure {
   $self->add_plugins(
     # tweet releases. because i can.
     'Twitter' ,
+    # git magic
+    'Git::Commit',
+    'Git::Tag',
     # install dist after release
     [ 'InstallRelease' => { install_command => 'cpanm .' } ] ,
   );
@@ -165,7 +171,7 @@ Dist::Zilla::PluginBundle::GENEHACK - BeLike::GENEHACK when you zilla your dist
 
 =head1 VERSION
 
-version 0.3
+version 0.4
 
 =head1 SYNOPSIS
 
@@ -192,9 +198,10 @@ this:
     [MetaJSON]
     [GithubMeta]
     [Repository]
-    github_http = 0
     [InstallGuide]
-    [ReadmeFromPod]
+    [ReadmeMarkdownFromPod]
+    [CopyFilesFromBuild]
+    copy = README.mkdn
     [ExtraTests]
     [PodCoverageTests]
     [PodSyntaxTests]
@@ -202,6 +209,8 @@ this:
     [Test::Compile]
     [Test::Kwalitee]
     [Twitter]
+    [Git::Commit]
+    [Git::Tag]
     [ArchiveRelease]
     [InstallRelease]
     [NextRelease]
